==> ng2-page-transition-0.2.5.tgz: package/src/ng2-page-transition.component.js <==
"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var core_1 = require('@angular/core');
var router_1 = require('@angular/router');
var default_transition_animation_1 = require('./default-transition.animation');
var Ng2PageTransition = (function () {
    function Ng2PageTransition(router) {
        var _this = this;
        this.router = router;
        this.scrollTop = true;
        this.onlyOnRoutes = [""];
        this.animation = {
            state: "leave",
            custom: false,
            enterDelay: 0
        };
        this.animation.state = "leave";
        router.events.subscribe(function (event) {
            for (var i = 0; i < _this.onlyOnRoutes.length; i++) {
                if (event.url && event.url.indexOf(_this.onlyOnRoutes[i]) > -1) {
                    if (event instanceof router_1.NavigationStart) {
                        _this.animation.state = "leave";
                        _this.delayPromise = new Promise(function (resolve, reject) {
                            window.setTimeout(function () {
                                resolve(true);
                            }, _this.animation.enterDelay);
                        });
                    }
                    else if (event instanceof router_1.NavigationEnd) {
                        if (typeof _this.delayPromise !== "undefined") {
                            _this.delayPromise.then(function () {
                                _this.animation.state = "out";
                                if (_this.scrollTop) {
                                    window.scrollTo(0, 0);
                                }
                                setTimeout(function () {
                                    _this.animation.state = "enter";
                                }, 0);
                            });
                        }
                        else {
                            _this.animation.state = "out";
                            if (_this.scrollTop) {
                                window.scrollTo(0, 0);
                            }
                            setTimeout(function () {
                                _this.animation.state = "enter";
                            }, 0);
                        }
                    }
                    return;
                }
            }
        });
    }
    __decorate([
        core_1.Input(), 
        __metadata('design:type', Boolean)
    ], Ng2PageTransition.prototype, "scrollTop", void 0);
    __decorate([
        core_1.Input(), 
        __metadata('design:type', Array)
    ], Ng2PageTransition.prototype, "onlyOnRoutes", void 0);
    __decorate([
        core_1.Input(), 
        __metadata('design:type', Object)
    ], Ng2PageTransition.prototype, "animation", void 0);
    Ng2PageTransition = __decorate([
        core_1.Component({
            selector: 'ng2-page-transition',
            template: '<div [@ng2ElementState]="animation.custom || animation.state"><ng-content></ng-content></div>',
            animations: [default_transition_animation_1.defaultPageTransition()],
        }), 
        __metadata('design:paramtypes', [router_1.Router])
    ], Ng2PageTransition);
    return Ng2PageTransition;
}());
exports.Ng2PageTransition = Ng2PageTransition;

==> ng2-page-transition-0.2.6.tgz: package/src/ng2-page-transition.component.js <==
"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var core_1 = require('@angular/core');
var router_1 = require('@angular/router');
var default_transition_animation_1 = require('./default-transition.animation');
var Ng2PageTransition = (function () {
    function Ng2PageTransition(router) {
        var _this = this;
        this.router = router;
        this.scrollTop = true;
        this.onlyOnRoutes = [""];
        this.animation = {
            state: "leave",
            custom: false,
            enterDelay: 0
        };
        this.animation.state = "leave";
        router.events.subscribe(function (event) {
            for (var i = 0; i < _this.onlyOnRoutes.length; i++) {
                if (event.url && event.url.indexOf(_this.onlyOnRoutes[i]) > -1) {
                    if (event instanceof router_1.NavigationStart) {
                        _this.animation.state = "leave";
                        _this.delayPromise = new Promise(function (resolve, reject) {
                            window.setTimeout(function () {
                                resolve(true);
                            }, _this.animation.enterDelay);
                        });
                    }
                    else if (event instanceof router_1.NavigationEnd || event instanceof router_1.NavigationCancel) {
                        if (typeof _this.delayPromise !== "undefined") {
                            _this.delayPromise.then(function () {
                                _this.animation.state = "out";
                                if (_this.scrollTop) {
                                    window.scrollTo(0, 0);
                                }
                                setTimeout(function () {
                                    _this.animation.state = "enter";
                                }, 0);
                            });
                        }
                        else {
                            _this.animation.state = "out";
                            if (_this.scrollTop) {
                                window.scrollTo(0, 0);
                            }
                            setTimeout(function () {
                                _this.animation.state = "enter";
                            }, 0);
                        }
                    }
                    return;
                }
            }
        });
    }
    __decorate([
        core_1.Input(), 
        __metadata('design:type', Boolean)
    ], Ng2PageTransition.prototype, "scrollTop", void 0);
    __decorate([
        core_1.Input(), 
        __metadata('design:type', Array)
    ], Ng2PageTransition.prototype, "onlyOnRoutes", void 0);
    __decorate([
        core_1.Input(), 
        __metadata('design:type', Object)
    ], Ng2PageTransition.prototype, "animation", void 0);
    Ng2PageTransition = __decorate([
        core_1.Component({
            selector: 'ng2-page-transition',
            template: '<div [@ng2ElementState]="animation.custom || animation.state"><ng-content></ng-content></div>',
            animations: [default_transition_animation_1.defaultPageTransition()],
        }), 
        __metadata('design:paramtypes', [(typeof (_a = typeof router_1.Router !== 'undefined' && router_1.Router) === 'function' && _a) || Object])
    ], Ng2PageTransition);
    return Ng2PageTransition;
    var _a;
}());
exports.Ng2PageTransition = Ng2PageTransition;
